@@ -1,6 +1,8 @@
+import pdb
 import requests
 import time
 
+from stoobly_agent.app.models.adapters.stoobly_request_adapter import StooblyRequestAdapter
 from stoobly_agent.app.models.schemas.request import Request
 
 class ReplayContext():
@@ -14,6 +16,11 @@ class ReplayContext():
 
     self.__sequence = None
 
+  @classmethod
+  def from_python_request(cls, request: requests.Request):
+    stoobly_request = StooblyRequestAdapter(request).adapt()
+    return cls(Request(stoobly_request))
+
   @property
   def end_time(self):
     return self.__end_time
