@@ -4,11 +4,14 @@ import pdb
 import requests
 import sys
 
+from stoobly_agent.app.cli.helpers.context import ReplayContext
 from stoobly_agent.app.cli.helpers.handle_replay_service import DEFAULT_FORMAT, JSON_FORMAT, handle_before_replay, print_request
 from stoobly_agent.app.cli.helpers.handle_test_service import SessionContext, exit_on_failure, handle_test_complete, handle_test_session_complete
 from stoobly_agent.app.cli.helpers.print_service import select_print_options
 from stoobly_agent.app.cli.helpers.test_facade import TestFacade
+from stoobly_agent.config.constants import mode
 from stoobly_agent.app.proxy.replay.body_parser_service import decode_response
+from stoobly_agent.app.proxy.replay.replay_request_service import replay as replay_request
 from stoobly_agent.app.settings import Settings
 from stoobly_agent.config.constants import alias_resolve_strategy, env_vars, test_filter, test_strategy
 from stoobly_agent.lib import logger
@@ -16,6 +19,7 @@ from stoobly_agent.lib.api.keys.request_key import InvalidRequestKey
 from stoobly_agent.lib.utils import jmespath
 from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
+from .helpers.handle_mock_service import print_raw_response, RAW_FORMAT
 from .helpers.print_service import print_requests
 from .helpers.request_facade import RequestFacade
 from .helpers.validations import *
@@ -38,7 +42,7 @@ def request(ctx):
 )
 @click.option('--page', default=0)
 @ConditionalDecorator(lambda f: click.option('--project-key')(f), is_remote)
-@ConditionalDecorator(lambda f: click.option('--scenario-key')(f), is_remote)
+@click.option('--scenario-key')
 @click.option('--select', multiple=True, help='Select column(s) to display.')
 @click.option('--sort-by', default='created_at', help='created_at|path')
 @click.option('--sort-order', default='desc', help='asc | desc')
@@ -68,16 +72,16 @@ def list(**kwargs):
 @request.command(
   help="Replay a request"
 )
-@click.option(
+@ConditionalDecorator(lambda f: click.option(
     '--alias-resolve-strategy', 
     default=alias_resolve_strategy.NONE, 
     type=click.Choice([alias_resolve_strategy.NONE, alias_resolve_strategy.FIFO, alias_resolve_strategy.LIFO]), 
     help='Strategy for resolving dynamic values for aliases.'
-)
-@click.option('--assign', multiple=True, help='Assign alias values. Format: <NAME>=<VALUE>')
+)(f), is_remote)
+@ConditionalDecorator(lambda f: click.option('--assign', multiple=True, help='Assign alias values. Format: <NAME>=<VALUE>')(f), is_remote)
 @click.option('--format', default=DEFAULT_FORMAT, type=click.Choice([DEFAULT_FORMAT, JSON_FORMAT]), help='Format replay response.')
 @click.option('--host', help='Rewrite request host.')
-@click.option('--group-by', help='Repeat for each alias name.')
+@ConditionalDecorator(lambda f: click.option('--group-by', help='Repeat for each alias name.')(f), is_remote)
 @click.option('--lifecycle-hooks-script-path', help='Path to lifecycle hooks script.')
 @click.option(
   '--log-level', default=logger.WARNING, type=click.Choice(log_levels), 
@@ -86,10 +90,10 @@ def list(**kwargs):
   '''
 )
 @click.option('--record', is_flag=True, default=False, help='Replay and record request.')
-@ConditionalDecorator(lambda f: click.option('--scenario-key', help='Record to scenario.')(f), is_remote)
+@click.option('--scenario-key', help='Record to scenario.')
 @click.option('--scheme', help='Rewrite request scheme.')
-@click.option('--trace-id', help='Use existing trace.')
-@click.option('--validate', multiple=True, help='Validate one or more aliases. Format: <NAME>=?<TYPE>')
+@ConditionalDecorator(lambda f: click.option('--trace-id', help='Use existing trace.')(f), is_remote)
+@ConditionalDecorator(lambda f: click.option('--validate', multiple=True, help='Validate one or more aliases. Format: <NAME>=?<TYPE>')(f), is_remote)
 @click.argument('request_key')
 def replay(**kwargs):
   os.environ[env_vars.LOG_LEVEL] = kwargs['log_level']
@@ -103,7 +107,7 @@ def replay(**kwargs):
 
     validate_scenario_key(kwargs['scenario_key'])
 
-  if len(kwargs['validate']):
+  if 'validate' in kwargs and len(kwargs['validate']):
       validate_aliases(kwargs['validate'], assign=kwargs['assign'], format=kwargs['format'], trace_id=kwargs['trace_id'])
 
   __assign_default_alias_resolve_strategy(kwargs)
@@ -183,6 +187,44 @@ if is_remote:
 
     exit_on_failure(session_context, format=kwargs['format'])
 
+@request.command(
+  help="Mock request"
+)
+@click.option('-d', '--data', default='', help='HTTP POST data')
+@click.option('--format', type=click.Choice([RAW_FORMAT]), help='Format response')
+@click.option('-H', '--header', multiple=True, help='Pass custom header(s) to server')
+@ConditionalDecorator(lambda f: click.option('--project-key')(f), is_remote)
+@click.option('-X', '--request', default='GET', help='Specify request command to use')
+@click.option('--scenario-key')
+@click.argument('url')
+def mock(**kwargs):
+  headers = {}
+  for header in kwargs['header']:
+    toks = header.split(':')
+
+    if len(toks) != 2:
+      continue
+    
+    headers[toks[0]] = toks[1]
+
+  request = requests.Request(
+    data=kwargs['data'],
+    headers=headers,
+    method=kwargs['request'],
+    url=kwargs['url']
+  )
+
+  context = ReplayContext.from_python_request(request)
+  response: requests.Response = replay_request(context, {
+    **kwargs,
+    'mode': mode.MOCK,
+  })
+
+  if kwargs['format'] == RAW_FORMAT:
+    print_raw_response(response)
+  else:
+    print(response.content.decode())
+
 @click.group(
   epilog="Run 'stoobly-agent request response COMMAND --help' for more information on a command.",
   help="Manage request responses"
@@ -203,9 +245,11 @@ def get(**kwargs):
 
   print(res.content)
 
-@response.command()
+@response.command(
+  help="Query properties in response"
+)
 @click.option('--query', required=True)
-@click.argument('request-key')
+@click.argument('request_key')
 def query(**kwargs):
   validate_request_key(kwargs['request_key'])
 
@@ -218,12 +262,6 @@ def query(**kwargs):
 
   print(jmespath.search(kwargs['query'], decoded_response))
 
-@response.command(
-  help="Set new mocked response"
-)
-def set(**kwargs):
-  print("Not yet implemented. Stay tuned!")
-
 request.add_command(response)
 
 def __replay(handler, kwargs) -> requests.Response:
@@ -238,5 +276,5 @@ def __replay(handler, kwargs) -> requests.Response:
 
 def __assign_default_alias_resolve_strategy(kwargs):
     # If we have assigned values to aliases, it's likely we want to also have them resolved
-    if len(kwargs['assign']) > 0 and kwargs['alias_resolve_strategy'] == alias_resolve_strategy.NONE:
+    if 'assign' in kwargs and len(kwargs['assign']) > 0 and kwargs['alias_resolve_strategy'] == alias_resolve_strategy.NONE:
         kwargs['alias_resolve_strategy'] = alias_resolve_strategy.FIFO
\ No newline at end of file
