@@ -1,11 +1,9 @@
-from typing import Union
-
 from stoobly_agent.lib.orm.request import Request
 from stoobly_agent.lib.api.requests_resource import RequestsResource
 from stoobly_agent.app.settings import RemoteSettings
 
 from .local_db.request_adapter import LocalDBRequestAdapter
-from .stoobly_request_adapter import StooblyRequestAdapter
+from .stoobly.request_adapter import StooblyRequestAdapter
 
 class RequestAdapterFactory():
 
