@@ -1,4 +1,5 @@
 from stoobly_agent.app.proxy.replay.alias_resolver import AliasResolver
+from stoobly_agent.lib.orm.trace_alias import TraceAlias
 
 class AliasContext():
 
@@ -17,4 +18,7 @@ class AliasContext():
   def resolve_alias(self, alias_name: str, value: str):
     trace_alias = self.alias_resolver.resolve_alias(alias_name, value)
     self.resolved_aliases.append(trace_alias)
-    return trace_alias
\ No newline at end of file
+    return trace_alias
+
+  def assign_alias(self, trace_alias: TraceAlias, value):
+    self.__alias_resolver.assign_alias(trace_alias, value)
\ No newline at end of file
