@@ -5,16 +5,17 @@ import requests
 from http.cookies import SimpleCookie
 from typing import Callable, TypedDict, Union
 
+from stoobly_agent.app.cli.ca_cert_installer import CACertInstaller
 from stoobly_agent.app.cli.helpers.context import ReplayContext
 from stoobly_agent.app.models.schemas.request import Request
 from stoobly_agent.app.proxy.intercept_settings import InterceptSettings
 from stoobly_agent.app.proxy.mitmproxy.request_facade import MitmproxyRequestFacade
 from stoobly_agent.app.proxy.replay.trace_context import TraceContext
+from stoobly_agent.app.proxy.simulate_intercept_service import simulate_intercept
 from stoobly_agent.app.settings import Settings
 from stoobly_agent.config.constants import alias_resolve_strategy, custom_headers, request_origin, test_filter, test_strategy
 from stoobly_agent.config.mitmproxy import MitmproxyConfig
-from stoobly_agent.config.constants import mode
-from stoobly_agent.lib.api.api import Api
+from stoobly_agent.config.constants import mock_policy, mode
 
 class ReplayRequestOptions(TypedDict):
   alias_resolve_strategy: alias_resolve_strategy.AliasResolveStrategy
@@ -25,6 +26,7 @@ class ReplayRequestOptions(TypedDict):
   before_replay: Union[Callable[[ReplayContext], None], None]
   after_replay: Union[Callable[[ReplayContext], Union[requests.Response, None]], None]
   project_key: Union[str, None]
+  proxies: dict
   report_key: Union[str, None] 
   request_origin: Union[request_origin.CLI, None] 
   scenario_key: Union[str, None] 
@@ -37,10 +39,9 @@ def replay_with_trace(context: ReplayContext, trace_context: TraceContext, optio
   trace_context.alias_resolve_strategy = options.get('alias_resolve_strategy')
   return trace_context.with_replay_context(context, lambda context: replay(context, options))
 
-def replay_with_rewrite(context: ReplayContext) -> requests.Response:
-  return replay(context, {
-      'before_replay': __handle_before_replay
-  })
+def replay_with_rewrite(context: ReplayContext, options: ReplayRequestOptions = {}) -> requests.Response:
+  __rewrite_before_replay(context)
+  return replay(context, options)
 
 def replay(context: ReplayContext, options: ReplayRequestOptions) -> requests.Response:
   if 'before_replay' in options and callable(options['before_replay']):
@@ -48,6 +49,8 @@ def replay(context: ReplayContext, options: ReplayRequestOptions) -> requests.Re
 
   request = context.request
   headers = request.headers
+  method = request.method
+  cookies = __get_cookies(headers)
 
   if options.get('host'):
     request.host = options['host']
@@ -56,48 +59,70 @@ def replay(context: ReplayContext, options: ReplayRequestOptions) -> requests.Re
   if options.get('scheme'):
     request.scheme = options['scheme']
 
-  if 'alias_resolve_strategy' in options:
+  if options.get('alias_resolve_strategy'):
     headers[custom_headers.ALIAS_RESOLVE_STRATEGY] = options['alias_resolve_strategy']
 
-  if 'lifecycle_hooks_script_path' in options:
+  if options.get('lifecycle_hooks_script_path'):
     __handle_lifecycle_hooks_script_path(options['lifecycle_hooks_script_path'], headers) 
 
-  if 'mode' in options:
+  if options.get('mode'):
     __handle_mode_option(options['mode'], request, headers)
 
-  if 'project_key' in options:
+  if options.get('project_key'):
     headers[custom_headers.PROJECT_KEY] = options['project_key']
 
-  if 'report_key' in options:
+  if options.get('report_key'):
     headers[custom_headers.REPORT_KEY] = options['report_key']
 
-  if 'request_origin' in options:
+  if options.get('request_origin'):
     headers[custom_headers.REQUEST_ORIGIN] = options['request_origin']
 
-  if 'scenario_key' in options:
+  if options.get('scenario_key'):
     headers[custom_headers.SCENARIO_KEY] = options['scenario_key']
 
-  if 'test_filter' in options:
+  if options.get('test_filter'):
     headers[custom_headers.TEST_FILTER] = options['test_filter']
 
-  if 'test_strategy' in options:
+  if options.get('test_strategy'):
     headers[custom_headers.TEST_STRATEGY] = options['test_strategy']
 
-  method = request.method
-  handler = getattr(requests, method.lower())
-  cookies = __get_cookies(request.headers)
+  request_config = {
+    'allow_redirects': True,
+    'stream': True,
+    'verify': not MitmproxyConfig.instance().get('ssl_insecure')
+  }
+  request_dict = {
+    'cookies': cookies,
+    'data': request.body,
+    'headers': headers, 
+    #'params': request.query_params, # Do not send query params, they should be a part of the URL
+  }
 
-  # Set proxy env vars to ensure request gets sent to proxy
-  res: requests.Response = Api().with_proxy(lambda: handler(
-    request.url, 
-    allow_redirects = True,
-    cookies = cookies,
-    data=request.body,
-    headers=headers, 
-    #params=request.query_params, # Do not send query params, they should be a part of the URL
-    stream = True,
-    verify = not MitmproxyConfig.instance().get('ssl_insecure')
-  ))
+  res: requests.Response = None
+  if not options.get('proxy'):
+    request = requests.Request(**{
+      **request_dict,
+      'method': method,
+      'url': request.url,
+    })
+
+    res = simulate_intercept(request, **request_config)
+  else:
+    settings = Settings.instance()
+    handler = getattr(requests, method.lower())
+
+    res = handler(
+      request.url, 
+      **{
+        **request_config,
+        **request_dict,
+        'proxies': {
+          'http': settings.proxy.url,
+          'https': settings.proxy.url,
+        },
+        'verify': CACertInstaller().mitm_crt_absolute_path if request_config['verify'] else False,
+      }
+    )
 
   if 'after_replay' in options and callable(options['after_replay']):
     context.with_response(res)
@@ -119,7 +144,10 @@ def __handle_mode_option(_mode, request: Request, headers):
 
   if _mode == mode.MOCK or _mode == mode.TEST:
     # If mocking or testing, we already know which request to get response from 
-    headers[custom_headers.MOCK_REQUEST_ID] = str(request.id)
+    if request.id:
+      headers[custom_headers.MOCK_REQUEST_ID] = str(request.id)
+
+    headers[custom_headers.MOCK_POLICY] = mock_policy.ALL
   elif _mode == mode.RECORD:
     # If recording, then it's actually a replay and record
     headers[custom_headers.PROXY_MODE] = mode.REPLAY
@@ -129,7 +157,7 @@ def __get_cookies(headers: Request.headers):
   cookies = SimpleCookie(headers.get('Cookie')).items()
   return {k: v.value for k, v in cookies}
 
-def __handle_before_replay(context: ReplayContext):
+def __rewrite_before_replay(context: ReplayContext):
   request = context.request
   request_facade = MitmproxyRequestFacade(request)
   intercept_settings = InterceptSettings(Settings.instance())
