@@ -3,12 +3,14 @@ import os
 import pdb
 import sys
 
+from stoobly_agent import VERSION
 from stoobly_agent.config.constants import env_vars
+from stoobly_agent.config.data_dir import DataDir
 from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
 from .app.api import run as run_api
-from .app.cli import ca_cert, config, feature, intercept, MainGroup, project, request, trace
-from .app.proxy import CONNECTION_STRATEGIES, INTERCEPT_MODES, run as run_proxy
+from .app.cli import ca_cert, config, feature, intercept, MainGroup, request, scenario, trace
+from .app.proxy import CONNECTION_STRATEGIES, run as run_proxy
 from .app.settings import Settings
 from .lib import logger
 from .lib.orm.migrate_service import migrate as migrate_database
@@ -16,6 +18,9 @@ from .lib.orm.migrate_service import migrate as migrate_database
 settings = Settings.instance()
 is_remote = settings.cli.features.remote
 
+# Makes sure database is up to date
+migrate_database(VERSION)
+
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 @click.version_option()
@@ -34,6 +39,7 @@ main.add_command(config)
 main.add_command(feature)
 main.add_command(intercept)
 main.add_command(request)
+main.add_command(scenario)
 main.add_command(trace)
 
 if settings.cli.features.dev_tools:
@@ -45,10 +51,15 @@ if settings.cli.features.exec:
     ExecDecorator(main).decorate()
 
 if settings.cli.features.remote:
-    from .app.cli import report, scenario
+    from .app.cli import project, report
     main.add_command(project)
     main.add_command(report)
-    main.add_command(scenario)
+
+@main.command(
+    help="Initialize a new context"
+)
+def init(**kwargs):
+    DataDir.instance().create()
 
 @main.command(
     help="Run proxy and/or UI",
@@ -56,7 +67,6 @@ if settings.cli.features.remote:
 @ConditionalDecorator(lambda f: click.option('--api-url', help='API URL.')(f), is_remote)
 @click.option('--headless', is_flag=True, default=False, help='Disable starting UI.')
 @click.option('--connection-strategy', help=', '.join(CONNECTION_STRATEGIES), type=click.Choice(CONNECTION_STRATEGIES))
-@click.option('--intercept-mode', help=', '.join(INTERCEPT_MODES), type=click.Choice(INTERCEPT_MODES))
 @click.option('--log-level', default=logger.INFO, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), help='''
     Log levels can be "debug", "info", "warning", or "error"
 ''')
@@ -83,10 +93,4 @@ def run(**kwargs):
     if 'headless' in kwargs and not kwargs['headless']:
         run_api(**kwargs)
 
-    if kwargs['intercept_mode'] and kwargs['intercept_mode'] not in INTERCEPT_MODES:
-        print(f"Error: Invalid value for --intercept-mode, values: {', '.join(INTERCEPT_MODES)}", file=sys.stderr)
-        sys.exit(1)
-
-    migrate_database()
-
     run_proxy(**kwargs)
\ No newline at end of file
