@@ -1,5 +1,7 @@
 from .resource_key import ResourceKey
 
+LOCAL_PROJECT_ID = 0
+
 class InvalidProjectKey(Exception):
   pass
 
@@ -14,6 +16,10 @@ class ProjectKey(ResourceKey):
     if not self.organization_id:
       raise InvalidProjectKey('Missing organization_id')
 
+  @property
+  def is_local(self) -> bool:
+    return int(self.id) == LOCAL_PROJECT_ID
+
   @property
   def id(self) -> str:
     return self.get('i')
